#########
py2latex
#########

.. start short_desc

**Create LaTeX documents with Python, Markdown and Jinja2.**

.. end short_desc

This project is at a VERY early stage, and as such things might not work and WILL break between versions.

.. start shields 

.. list-table::
	:stub-columns: 1
	:widths: 10 90

	* - Docs
	  - |docs| |docs_check|
	* - Tests
	  - |travis| |actions_windows| |actions_macos| |codefactor|
	* - PyPI
	  - |pypi-version| |supported-versions| |supported-implementations| |wheel|
	* - Activity
	  - |commits-latest| |commits-since| |maintained|
	* - Other
	  - |license| |language| |requires|

.. |docs| image:: https://img.shields.io/readthedocs/py2latex/latest?logo=read-the-docs
	:target: https://py2latex.readthedocs.io/en/latest/?badge=latest
	:alt: Documentation Status
	
.. |docs_check| image:: https://github.com/domdfcoding/py2latex/workflows/Docs%20Check/badge.svg
	:target: https://github.com/domdfcoding/py2latex/actions?query=workflow%3A%22Docs+Check%22
	:alt: Docs Check Status

.. |travis| image:: https://img.shields.io/travis/com/domdfcoding/py2latex/master?logo=travis
	:target: https://travis-ci.com/domdfcoding/py2latex
	:alt: Travis Build Status

.. |actions_windows| image:: https://github.com/domdfcoding/py2latex/workflows/Windows%20Tests/badge.svg
	:target: https://github.com/domdfcoding/py2latex/actions?query=workflow%3A%22Windows+Tests%22
	:alt: Windows Tests Status

.. |actions_macos| image:: https://github.com/domdfcoding/py2latex/workflows/macOS%20Tests/badge.svg
	:target: https://github.com/domdfcoding/py2latex/actions?query=workflow%3A%22macOS+Tests%22
	:alt: macOS Tests Status

.. |requires| image:: https://requires.io/github/domdfcoding/py2latex/requirements.svg?branch=master
	:target: https://requires.io/github/domdfcoding/py2latex/requirements/?branch=master
	:alt: Requirements Status

.. |codefactor| image:: https://img.shields.io/codefactor/grade/github/domdfcoding/py2latex?logo=codefactor
	:target: https://www.codefactor.io/repository/github/domdfcoding/py2latex
	:alt: CodeFactor Grade

.. |pypi-version| image:: https://img.shields.io/pypi/v/py2latex
	:target: https://pypi.org/project/py2latex/
	:alt: PyPI - Package Version

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/py2latex
	:target: https://pypi.org/project/py2latex/
	:alt: PyPI - Supported Python Versions

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/py2latex
	:target: https://pypi.org/project/py2latex/
	:alt: PyPI - Supported Implementations

.. |wheel| image:: https://img.shields.io/pypi/wheel/py2latex
	:target: https://pypi.org/project/py2latex/
	:alt: PyPI - Wheel

.. |license| image:: https://img.shields.io/github/license/domdfcoding/py2latex
	:alt: License
	:target: https://github.com/domdfcoding/py2latex/blob/master/LICENSE

.. |language| image:: https://img.shields.io/github/languages/top/domdfcoding/py2latex
	:alt: GitHub top language

.. |commits-since| image:: https://img.shields.io/github/commits-since/domdfcoding/py2latex/v0.0.4
	:target: https://github.com/domdfcoding/py2latex/pulse
	:alt: GitHub commits since tagged version

.. |commits-latest| image:: https://img.shields.io/github/last-commit/domdfcoding/py2latex
	:target: https://github.com/domdfcoding/py2latex/commit/master
	:alt: GitHub last commit

.. |maintained| image:: https://img.shields.io/maintenance/yes/2020
	:alt: Maintenance

.. end shields

|

Installation
--------------

.. start installation

``py2latex`` can be installed from PyPI.

To install with ``pip``:

.. code-block:: bash

	$ python -m pip install py2latex

.. end installation
